#collapsing data to before/after averages per duflo et al 2004 

# a function that finds states with pre paralel trends with Rhode Island
find_parallel_trends <- function(vname, pval.threshold){
  parallel_states <- c()
  for(s in unique(df$state)){
    if(s == "RI"){
      next
    }
    formula <- paste("log(",vname,") ~ state + timedummy + log_nstores*state + ri*qy  + ", other_states_policies)
    formula <- as.formula(formula)
    tmp <- subset(df, state %in% c("RI",s))
    reg <- lm(formula  , tmp)
    reg.coef <- coef(summary(reg))

    lbls <- labels(reg.coef)[[1]]
    qvars <- c("ri:qy2009_2","ri:qy2009_3","ri:qy2009_4","ri:qy2010_1","ri:qy2010_2")
    tests <- c()
    for(qv in qvars){
      if(qv %in% lbls){
        tests <- c(tests, paste(qv, "=0", sep = "") )
      }
    }
    
    test.result <- linearHypothesis(reg, tests, singular.ok=T)
    
    if(test.result$`Pr(>F)`[2] > pval.threshold){
      parallel_states <- c(parallel_states, s)
    }
  }
  
  return(parallel_states)
}
####### end of function


#function that returns the number of stars based on significance level
stars = function(tstat, degfree){
#  degfree <- 1000
  tstat <- -abs(tstat)
  nstars <- 0
  if(tstat < qt(0.005,degfree)){ # 1% significance
    nstars <- 3
  }
  else if(tstat < qt(0.025,degfree)){ # 5% significance level
    nstars <- 2
  }
  else if(tstat < qt(0.05,degfree)){ # 10% significance levwl
    nstars <- 1
  }
  return(nstars)
}
#### end of stars function

# regression results are saved in this data frame
reg.results = data.frame(
  "VariableName" = c(),
  "baseline" = c(),
  "SP1CG1" = c(),
  "SP1CG2" = c(),
  "SP1CG3" = c(),
  "SP2CG1" = c(),
  "SP2CG2" = c(),
  "SP2CG3" = c()
)


# a list of variables (and their labels) for which we want to do regressions
varname_label <- read.csv("data/varname_label_for_regs.csv", stringsAsFactors=FALSE)


# find regression results for all variables, all specifications and all control groups
for(i in 1:NROW(varname_label)){
  
  msg <- paste("calculating results for", varname_label[i,"varname"] , "\n")
  cat(msg)
  
  #take out the effect of other vars and get residuals
  f_de1 = paste("log(",varname_label[i,"varname"],") ~ state + t + log_nstores + ", other_states_policies)
  f_de2 = paste("log(",varname_label[i,"varname"],") ~ state + t + log_nstores +  log_pi_per_capita + log_unemp_rate + ", other_states_policies)
  #do a simple diff and diff (panel of only 2 periods) on residuals
  f1 <- paste("y_mean1 ~ state + after + ri_after")
  f2 <- paste("y_mean2 ~ state + after + ri_after")

  f_de1 = as.formula(f_de1)
  f_de2 = as.formula(f_de2)
  f1 <- as.formula(f1)
  f2 <- as.formula(f2)
  
  cg1 <- df
  cg2 <- subset(df, state=="RI" | state %in% find_parallel_trends(varname_label[i,"varname"], 0.10) )
  cg3 <- df_restrcited
  
  cg1 <- cg1[!is.na(cg1[,varname_label[i,"varname"]]), ]
  cg2 <- cg2[!is.na(cg2[,varname_label[i,"varname"]]), ]
  cg3 <- cg3[!is.na(cg3[,varname_label[i,"varname"]]), ]
  
  tmpreg <- lm(f_de1, cg1)
  cg1$yy11 <- resid(tmpreg)
  tmpreg <- lm(f_de2, cg1)
  cg1$yy21 <- resid(tmpreg)
  
  tmpreg <- lm(f_de1, cg2)
  cg2$yy12 <- resid(tmpreg)
  tmpreg <- lm(f_de2, cg2)
  cg2$yy22 <- resid(tmpreg)
  
  tmpreg <- lm(f_de1, cg3)
  cg3$yy13 <- resid(tmpreg)
  tmpreg <- lm(f_de2, cg3)
  cg3$yy23 <- resid(tmpreg)
  
  dt1 <- cg1 %>% group_by(state, after,ri, ri_after) %>% summarize(y_mean1 = mean(yy11), 
                                                                   y_mean2 = mean(yy21))
  
  dt2 <- cg2 %>% group_by(state, after,ri, ri_after) %>% summarize(y_mean1 = mean(yy12), 
                                                                   y_mean2 = mean(yy22))
  
  dt3 <- cg3 %>% group_by(state, after,ri, ri_after) %>% summarize(y_mean1 = mean(yy13), 
                                                                   y_mean2 = mean(yy23))
  
  reg11 <- lm(formula = f1, data = dt1)
  reg12 <- lm(formula = f1, data = dt2)
  reg13 <- lm(formula = f1, data = dt3)

  reg21 <- lm(formula = f2, data = dt1)
  reg22 <- lm(formula = f2, data = dt2)
  reg23 <- lm(formula = f2, data = dt3)

  coef11 <- coef(summary(reg11))
  coef12 <- coef(summary(reg12))
  coef13 <- coef(summary(reg13))

  coef21 <- coef(summary(reg21))
  coef22 <- coef(summary(reg22))
  coef23 <- coef(summary(reg23))


  baseline.value <- mean( df[df$ri==1 & df$after==0, varname_label[i,"varname"]], na.rm = T )
  
  n1 <- nobs(reg11)
  n2 <- nobs(reg12)
  n3 <- nobs(reg13)

  reg.results <- rbind(reg.results, data.frame(
    "VariableName" = c( varname_label[i,"label"], varname_label[i,"label"], varname_label[i,"label"], varname_label[i,"label"]),
    "baseline" = c( baseline.value, baseline.value, baseline.value, baseline.value),
    
    
    "SP1CG1" = c( coef11['ri_after',1], coef11['ri_after',2], stars(coef11['ri_after',3], n1/2-2), n1  ),
    "SP1CG2" = c( coef12['ri_after',1], coef12['ri_after',2], stars(coef12['ri_after',3], n2/2-2), n2  ),
    "SP1CG3" = c( coef13['ri_after',1], coef13['ri_after',2], stars(coef13['ri_after',3], n3/2-2), n3  ),

    "SP2CG1" = c( coef21['ri_after',1], coef21['ri_after',2], stars(coef21['ri_after',3], n1/2-2), n1  ),
    "SP2CG2" = c( coef22['ri_after',1], coef22['ri_after',2], stars(coef22['ri_after',3], n2/2-2), n2  ),
    "SP2CG3" = c( coef23['ri_after',1], coef23['ri_after',2], stars(coef23['ri_after',3], n3/2-2), n3  )
  ) )
}

write.csv(reg.results, file = "data/collapsed-DiD-results-2019.csv")
  
  