#set this path to where you're keeping this file
setwd("/Users/Amir/Dropbox/Research/JMP")

#Do not use schientific numbers in outputs
options(scipen=999)

#Do not cut output tables
options(tibble.print_max = Inf)

if(TRUE){ # installs all required packages. Change to TRUE when running for the first time
install.packages("sas7bdat")
install.packages("dplyr")
install.packages("ggplot2")
install.packages("tidyr")
install.packages("stringr")
install.packages("lubridate")
install.packages("clusterSEs")
install.packages("multiwayvcov")
install.packages("knitr" )
install.packages("kableExtra")
install.packages("tidyverse")
}

library("sas7bdat")
library("dplyr")
library("ggplot2")
library("stringr")
library("tidyr")
library("lubridate")
library("car")
library("clusterSEs")
library("multiwayvcov")
library("knitr" )
library("kableExtra")
library("car")
library("tidyverse")
library("reshape2")

#read SAS data file of state level aggregate variables
df <- read.csv("data/aggregated_data.csv")

laws <- read.csv('data/law-changes.csv')

#create monthly time variable 1 to 60
t = 1
for(year in 2009:2013){
  for(month in 1:12){
    laws[ laws$year==year & laws$month==month ,"t"] = t
    t = t + 1
  }
}


#remove states with incomplete periods
period_count <- df %>% group_by(state) %>% summarize(periods_per_state=n())
df <- merge(df, period_count, by="state", all.x = T)
df <- subset(df, periods_per_state==60)
df$state <- as.character(df$state)
remove(period_count)


#control for all payday loan law changes in other states, call them pol1, pol2, ...
laws$state <- as.character(laws$state)
other_states_policies <- c()
for(i in 1:NROW(laws)){
  varname <- paste("pol", i, sep = "")
  df[,varname] <- 0
  df[ df$state==laws[i,'state'] & df$t>=laws[i,'t'], varname ] <- 1
  other_states_policies <- c(other_states_policies, varname)
}
other_states_policies <- paste(other_states_policies, collapse = " + ")


#### attach personal income
pinc = read.csv("data/personal income.csv")
states = read.csv("data/states.csv")
pinc = merge(pinc, states, by.x="GeoName", by.y="State")
pinc = gather(pinc, y_q, pi, X2009Q1:X2013Q4)
pinc$state = as.character(pinc$Abbreviation)
pinc$y = as.numeric( substr(pinc$y_q,2,5)  )
pinc$q =  as.numeric( substr(pinc$y_q,7,7) )
df = merge(df, pinc[,c("y","q","state","pi")], by=c("y","q","state"), all.x = T)

#population
state_pop <- read.csv("data/population-by-state-year.csv")
state_pop <- gather(state_pop, y, pop, y2008:y2014)
state_pop$y <- as.numeric( substr(state_pop$y,2,5) )
state_pop2 <- state_pop
state_pop2$y <- state_pop$y - 1
state_pop2$next_year_pop <- state_pop2$pop
state_pop <- merge(state_pop, state_pop2[,c("GeoName","y","next_year_pop")], 
                   by=c("GeoName","y"), all.x = T)
state_pop3 <- state_pop
state_pop3$y <- state_pop$y + 1
state_pop3$prev_year_pop <- state_pop3$pop
state_pop <- merge(state_pop, state_pop3[,c("GeoName","y","prev_year_pop")], 
                   by=c("GeoName","y"), all.x = T)
y_m <- expand.grid(y=2008:2014, m=1:12)
state_pop <- merge(state_pop, y_m, by="y")
state_pop$pop_interpolated <- NA
state_pop <- subset(state_pop, y>=2009 & y<=2013)
state_pop$pop_interpolated[state_pop$m<=7] <- state_pop$pop[state_pop$m<=7] - 
  ((state_pop$pop[state_pop$m<=7] - state_pop$prev_year_pop[state_pop$m<=7])/12)*(7-state_pop$m[state_pop$m<=7])
state_pop$pop_interpolated[state_pop$m>7] <- state_pop$pop[state_pop$m>7] + 
  ((state_pop$next_year_pop[state_pop$m>7] - state_pop$pop[state_pop$m>7])/12)*(state_pop$m[state_pop$m>7]-7)
state_pop <- state_pop[order(state_pop$GeoName,state_pop$y,state_pop$m),]
state_pop <- merge(state_pop, states, by.x="GeoName", by.y="State")
state_pop$state <- as.character(state_pop$Abbreviation)
df <- merge(df, state_pop[,c("state","y","m","pop_interpolated")], 
            by=c("state","y","m"), all.x = T)
remove(pinc)
remove(states)
remove(state_pop)
remove(state_pop2)
remove(state_pop3)
##### end of attach personal income

### attach unemployment rate
unemp = read.csv("data/bls_unemp.csv", stringsAsFactors=FALSE)
df = merge(df, unemp[,c("y","m","state","unemp_rate")], by=c("y","m","state"), all.x = T)
remove(unemp)
## end attach unepmolyment rate


#prepare for regression
df$ri <- as.numeric(df$state=="RI")
df$after <- as.numeric(df$t>=19)
df$ri_after <- as.numeric(df$ri==1 & df$after==1)
df$timedummy = as.factor(df$t)
df$loanperperson <- df$nloans / df$nborrowers

########################################################

#### qy is a dummy for each quarter of each year, 2009Q1, 2009Q2, etc.
df$qy <- paste(as.character(df$y), as.character(df$q), sep = "_")
df$qy <- factor(df$qy)

df$log_nstores <- log(df$nstores)
df$log_pi <- log(df$pi)
df$log_pi_per_capita <- log(df$pi / df$pop_interpolated)
df$log_unemp_rate <- log(df$unemp_rate)
df$t_sq <- df$t ^ 2

#a dataset without states that had law changes
df_restrcited = subset(df,! state %in% unique(laws$state))





