# a function that finds states with pre paralel trends with Rhode Island
find_parallel_trends <- function(vname, pval.threshold){
  parallel_states <- c()
  for(s in unique(df$state)){
    if(s == "RI"){
      next
    }
    formula <- paste("log(",vname,") ~ state + timedummy + log_nstores*state + ri*qy  + ", other_states_policies)
    formula <- as.formula(formula)
    tmp <- subset(df, state %in% c("RI",s))
    reg <- lm(formula  , tmp)
    reg.coef <- coef(summary(reg))

    lbls <- labels(reg.coef)[[1]]
    qvars <- c("ri:qy2009_2","ri:qy2009_3","ri:qy2009_4","ri:qy2010_1","ri:qy2010_2")
    tests <- c()
    for(qv in qvars){
      if(qv %in% lbls){
        tests <- c(tests, paste(qv, "=0", sep = "") )
      }
    }
    
    test.result <- linearHypothesis(reg, tests, singular.ok=T)
    
    if(test.result$`Pr(>F)`[2] > pval.threshold){
      parallel_states <- c(parallel_states, s)
    }
  }
  
  return(parallel_states)
}
####### end of function


#function that returns the number of stars based on significance level
stars = function(tstat, degfree){
  tstat <- -abs(tstat)
  nstars <- 0
  if(tstat < qt(0.005,degfree)){ # 1% significance
    nstars <- 3
  }
  else if(tstat < qt(0.025,degfree)){ # 5% significance level
    nstars <- 2
  }
  else if(tstat < qt(0.05,degfree)){ # 10% significance levwl
    nstars <- 1
  }
  return(nstars)
}
#### end of stars function

# regression results are saved in this data frame
reg.results = data.frame(
  "VariableName" = c(),
  "baseline" = c(),
  "SP1CG1" = c(),
  "SP1CG2" = c(),
  "SP1CG3" = c(),
  "SP2CG1" = c(),
  "SP2CG2" = c(),
  "SP2CG3" = c(),
  "SP3CG1" = c(),
  "SP3CG2" = c(),
  "SP3CG3" = c()
)


# a list of variables (and their labels) for which we want to do regressions
varname_label <- read.csv("data/varname_label_for_regs.csv", stringsAsFactors=FALSE)

#bootstrap reps
bootstrap_reps <- 1000

# find regression results for all variables, all specifications and all control groups
for(i in 1:NROW(varname_label)){
  
  msg <- paste("calculating results for", varname_label[i,"varname"] , "\n")
  cat(msg)
  
  f1 <- paste("log(",varname_label[i,"varname"],") ~ state + timedummy + ", other_states_policies ," + log_nstores*state + ri_after")
  f2 <- paste("log(",varname_label[i,"varname"],") ~ state + timedummy + ", other_states_policies ," + log_nstores*state + log_pi_per_capita + log_unemp_rate + ri_after")
  f3 <- paste("log(",varname_label[i,"varname"],") ~ state + timedummy + ", other_states_policies ," + log_nstores*state + log_pi_per_capita + log_unemp_rate + state*t + state*t_sq + ri_after")

  f1 <- as.formula(f1)
  f2 <- as.formula(f2)
  f3 <- as.formula(f3)
  
  cg1 <- df
  cg2 <- subset(df, state=="RI" | state %in% find_parallel_trends(varname_label[i,"varname"], 0.10) )
  cg3 <- df_restrcited

  reg11 <- lm(formula = f1, data = cg1)
  reg12 <- lm(formula = f1, data = cg2)
  reg13 <- lm(formula = f1, data = cg3)

  reg21 <- lm(formula = f2, data = cg1)
  reg22 <- lm(formula = f2, data = cg2)
  reg23 <- lm(formula = f2, data = cg3)

  reg31 <- lm(formula = f3, data = cg1)
  reg32 <- lm(formula = f3, data = cg2)
  reg33 <- lm(formula = f3, data = cg3)

  #bootstrap
  cluster11 <- cluster.boot(reg11, ~state, parallel = T, use_white = NULL, force_posdef = FALSE, R = bootstrap_reps, boot_type = "wild", wild_type = "rademacher", debug = F)
  cluster12 <- cluster.boot(reg12, ~state, parallel = T, use_white = NULL, force_posdef = FALSE, R = bootstrap_reps, boot_type = "wild", wild_type = "rademacher", debug = F)
  cluster13 <- cluster.boot(reg13, ~state, parallel = T, use_white = NULL, force_posdef = FALSE, R = bootstrap_reps, boot_type = "wild", wild_type = "rademacher", debug = F)

  cluster21 <- cluster.boot(reg21, ~state, parallel = T, use_white = NULL, force_posdef = FALSE, R = bootstrap_reps, boot_type = "wild", wild_type = "rademacher", debug = F)
  cluster22 <- cluster.boot(reg22, ~state, parallel = T, use_white = NULL, force_posdef = FALSE, R = bootstrap_reps, boot_type = "wild", wild_type = "rademacher", debug = F)
  cluster23 <- cluster.boot(reg23, ~state, parallel = T, use_white = NULL, force_posdef = FALSE, R = bootstrap_reps, boot_type = "wild", wild_type = "rademacher", debug = F)

  cluster31 <- cluster.boot(reg31, ~state, parallel = T, use_white = NULL, force_posdef = FALSE, R = bootstrap_reps, boot_type = "wild", wild_type = "rademacher", debug = F)
  cluster32 <- cluster.boot(reg32, ~state, parallel = T, use_white = NULL, force_posdef = FALSE, R = bootstrap_reps, boot_type = "wild", wild_type = "rademacher", debug = F)
  cluster33 <- cluster.boot(reg33, ~state, parallel = T, use_white = NULL, force_posdef = FALSE, R = bootstrap_reps, boot_type = "wild", wild_type = "rademacher", debug = F)

  coef11 <- coeftest(reg11, cluster11)
  coef12 <- coeftest(reg12, cluster12)
  coef13 <- coeftest(reg13, cluster13)

  coef21 <- coeftest(reg21, cluster21)
  coef22 <- coeftest(reg22, cluster22)
  coef23 <- coeftest(reg23, cluster23)

  coef31 <- coeftest(reg31, cluster31)
  coef32 <- coeftest(reg32, cluster32)
  coef33 <- coeftest(reg33, cluster33)

  baseline.value <- mean( df[df$ri==1 & df$after==0, varname_label[i,"varname"]], na.rm = T )
  
  n1 <- nobs(reg11)
  n2 <- nobs(reg12)
  n3 <- nobs(reg13)

  reg.results <- rbind(reg.results, data.frame(
    "VariableName" = c( varname_label[i,"label"], varname_label[i,"label"], varname_label[i,"label"], varname_label[i,"label"]),
    "baseline" = c( baseline.value, baseline.value, baseline.value, baseline.value),
    
    
    "SP1CG1" = c( coef11['ri_after',1], coef11['ri_after',2], stars(coef11['ri_after',3], n1/60 - 2), n1  ),
    "SP1CG2" = c( coef12['ri_after',1], coef12['ri_after',2], stars(coef12['ri_after',3], n2/60 - 2), n2  ),
    "SP1CG3" = c( coef13['ri_after',1], coef13['ri_after',2], stars(coef13['ri_after',3], n3/60 - 2), n3  ),

    "SP2CG1" = c( coef21['ri_after',1], coef21['ri_after',2], stars(coef21['ri_after',3], n1/60 - 2), n1  ),
    "SP2CG2" = c( coef22['ri_after',1], coef22['ri_after',2], stars(coef22['ri_after',3], n2/60 - 2), n2  ),
    "SP2CG3" = c( coef23['ri_after',1], coef23['ri_after',2], stars(coef23['ri_after',3], n3/60 - 2), n3  ),

    "SP3CG1" = c( coef31['ri_after',1], coef31['ri_after',2], stars(coef31['ri_after',3], n1/60 - 2), n1  ),
    "SP3CG2" = c( coef32['ri_after',1], coef32['ri_after',2], stars(coef32['ri_after',3], n2/60 - 2), n2  ),
    "SP3CG3" = c( coef33['ri_after',1], coef33['ri_after',2], stars(coef33['ri_after',3], n3/60 - 2), n3  )
  ) )
}

write.csv(reg.results, file = "data/reg-results-2019-raw.csv")
  
  