# avg fees for RI (first stage)
dfg <- df[ df$state=="RI" , c("t","avgfee") ]
ggplot(dfg) +
  geom_point( aes(t,avgfee) ) +
  scale_x_continuous( name="Time (Months)", breaks=c(1,13,25,37,49), labels=c("2009-01","2010-01", 
                                                                              "2011-01","2012-01","2013-01") ) +
  scale_y_continuous(name="Avg Fee") +
  geom_vline(xintercept = 18.5, color="gray50") +
  theme(legend.title=element_blank(), legend.position="top")
# end of avg fees for RI (first stage)


# principal vs principal adjusted for Rhode Island
dfg <- df[ df$state=="RI" , c("t","avgprin","avgprin_adj") ]
dfg <- gather(dfg, principal_type , principal, c("avgprin","avgprin_adj"))
dfg$principal_type <- factor(dfg$principal_type, levels = c("avgprin","avgprin_adj"), labels = c("Actual","Adjusted"))

ggplot(dfg) +
  geom_line(  aes(t,principal, linetype = principal_type)) +
  scale_x_continuous( name="Time (Months)", breaks=c(1,13,25,37,49), labels=c("2009-01","2010-01", 
                                                                              "2011-01","2012-01","2013-01") ) +
  scale_y_continuous(name="Avg Principal") +
  geom_vline(xintercept = 18.5, color="gray50") +
  theme(legend.title=element_blank(), legend.position="top")

  scale_linetype_manual("principal_type", values = c("Actual","Adjusted") )
+ guides(fill = guide_legend(keywidth = 1, keyheight = 1),
         linetype=guide_legend(keywidth = 3, keyheight = 1),
         colour=guide_legend(keywidth = 3, keyheight = 1))
# end of principal vs principal adjusted for Rhode Island
  
  
  
#unrestricted price for different ranges of MC and beta (response of demand to price)
p0 <- .15
p1 <- .10
q0 <- 4700000 #million $
beta <- seq(0.16, 0.41, 0.0001)
mc <- seq(.02,.10,0.0001)

calcPrice <- function(beta_,mc_){
  b <- (p0-p1)/(beta_ * q0) #slope
  a <- p0 + b * q0    #intercept
  q <- (a - mc_) / (2*b) 
  p <- a - b * q
  return(p)
}
rrr <- expand.grid(beta=beta, mc=mc)  
rrr$p <- calcPrice(rrr$beta, rrr$mc)
rrr$realistic <- as.numeric(rrr$p >= .185 & rrr$p <= .22)

rrr$border <- 0
rrr$p1 <- calcPrice(rrr$beta + 0.0001, rrr$mc)
rrr$p2 <- calcPrice(rrr$beta - 0.0001, rrr$mc)
rrr$p3 <- calcPrice(rrr$beta, rrr$mc + 0.0001)
rrr$p4 <- calcPrice(rrr$beta, rrr$mc - 0.0001)
rrr$maxp <- apply(rrr[,c("p1","p2","p3","p4")],1,"max")
rrr$minp <- apply(rrr[,c("p1","p2","p3","p4")],1,"min")
rrr$border[rrr$realistic==1 & (rrr$maxp>.22 | rrr$minp<.185 | rrr$mc==.02
           | rrr$mc==.10 | rrr$beta==0.16 | rrr$beta==0.41) ] <- 1

ggplot(rrr, aes(beta, mc)) +
  geom_raster(aes(fill=p)) +
  scale_fill_gradient(low="white", high="black", name="Unrestricted Interest Rate") +
  geom_point( data = subset(rrr,border==1),  shape=19, size=0.001, color="red" ) +
  scale_x_continuous(name="Demand Response Estimate", limits = c(0.16, 0.41), expand = c(0, 0), breaks = seq(.16,0.41,0.02) ) +
  scale_y_continuous(name="Marginal Cost (per $1 lent)", limits = c(.02,.10), expand = c(0, 0), breaks = seq(.02,.10,.01)) 
#### end of unrestricted price graph



#welfare gain vs. welfare loss for different values of w (over-willingness to pay)
p0 <- .15
p1 <- .10
q0 <- 4700000 #million $
beta <- 0.3
q1 <- q0 * (1+beta)
m <- (p0-p1)/(q0-q1) #demand slope
a <- p0 - m * q0    #intercept
w <- seq(0,0.14,0.001)

qq <- data.frame(w = w)
qq$observed_gain <- ( ( (a-p1)*q1/2 ) - ( (a-p0)*q0/2 ) ) * 12 / 1000000
qq$q0_real <- -(a-qq$w-p0)/m
qq$q1_real <- -(a-qq$w-p1)/m
qq$real_gain <-   ( ( (a-qq$w-p1)*qq$q1_real/2 ) - ( (a-qq$w-p0)*qq$q0_real/2 ) ) * 12 / 1000000
qq$real_loss <- qq$observed_gain - qq$real_gain
qqq <- melt(qq[,c("w","real_gain","real_loss")], id="w")

ggplot(qqq) +
  geom_line(aes(x = w, y = value, color = variable), size=1.1) +
  scale_x_continuous(name="Over-willingness to Pay (w)", limits = c(0, 0.14), expand = c(0, 0), breaks = seq(0,0.14,0.02) ) +
  scale_y_continuous(name="Annual Welfare Gain/Loss ($Million)") +
  scale_color_manual(name = "", values = c("gray80","gray50"), labels = c("Real Gain","Real Loss")) + 
  theme(panel.background = element_rect(fill = 'gray96'))
#welfare gain vs. welfare loss for different values of w (over-willingness to pay)




################################ Rhode Island vs states in CG3 ##################################
## avg fee graph
dfg <- df_restrcited
temp <- dfg[dfg$t==18,c("avgfee","state")]
temp$val18 <- temp$avgfee
temp$avgfee <- NULL
dfg <- merge(dfg, temp, by="state")
dfg$y <- log(dfg$avgfee) - log(dfg$val18)

dfg$ri <- factor(dfg$ri, levels = c(1,0))
dfg$state <- factor(dfg$state, levels = c(unique(dfg$state[dfg$state!="RI"]),"RI"))
ggplot(dfg, aes(x=t,y=y, group=state,  color=ri))+
  geom_line() +
  scale_color_manual(name=c(), values=c("black","gray70"), labels = c("RI","Others")) +
  geom_vline(xintercept = 18.5, linetype=3) +  
  theme(panel.background = element_rect(fill = 'gray96')) +
  scale_y_continuous(name="Log(Avg Interest Rate)", limits = c(-0.5,0.5)) +
  scale_x_continuous( name=c(), limits = c(0,60), breaks=c(1,13,25,37,49), labels=c("2009-01","2010-01",
                                                                                    "2011-01","2012-01","2013-01") ) +
  theme(legend.position = "none")
## end avg fee graph


## number of borrowers graph
adjust_period <- c( rep(18,7), 16, 17 )
varname_label <- read.csv("data/varname_label_for_graphs.csv", stringsAsFactors=FALSE)
for(i in c(1:9)){
varname <- varname_label[i,"varname"]
varlabel <- paste("Log(",varname_label[i,"label"],")", sep = "")
cat(varlabel)
dfg <- df_restrcited
#dfg <- subset(df, state=="RI" | state %in% find_parallel_trends(varname, 0.10) )
dfg$y <- dfg[,varname]
dfg <- subset(dfg, !is.na(y))

dfg$ri <- factor(dfg$ri, levels = c(1,0))
dfg$state <- factor(dfg$state, levels = c(unique(dfg$state[dfg$state!="RI"]),"RI"))

fml <- paste("log(y) ~ log(nstores)*state + timedummy" , sep = "")
fml <- as.formula(fml)
reg.tmp <- lm( fml , dfg)
dfg$resid <- resid(reg.tmp)
temp <- dfg[dfg$t== adjust_period[i] ,c("resid","state")]
temp$val18 <- temp$resid
temp$resid <- NULL
dfg <- merge(dfg, temp, by="state")
dfg$yy <- dfg$resid - dfg$val18

gg <- ggplot(dfg[dfg$state!="SD",], aes(x=t,y=yy, group=state,  color=ri))+
  geom_line() +
  scale_color_manual(name=c(), values=c("black","gray70"), labels = c("RI","Others")) +
  geom_vline(xintercept = 18.5, linetype=3) +
  theme(panel.background = element_rect(fill = 'gray96')) +
  scale_y_continuous(name=varlabel) +
  scale_x_continuous( name=c(), limits = c(0,60), breaks=c(1,13,25,37,49), labels=c("2009-01","2010-01",
                                                                  "2011-01","2012-01","2013-01") ) +
  theme(legend.position = "none")

img.filename <- paste("compare-cg3-",varname, ".eps", sep = "")

ggsave(img.filename, plot = gg, device = "eps", path = "img/cg3",
       scale = 1, width = 4, height = 2, units = "in")

print(gg)
## end number of borrowers graph
}
################################ end of CG3 ##################################







################################ Rhode Island vs states in CG1 ##################################
## avg fee graph
dfg <- df
temp <- dfg[dfg$t==18,c("avgfee","state")]
temp$val18 <- temp$avgfee
temp$avgfee <- NULL
dfg <- merge(dfg, temp, by="state")
dfg$y <- log(dfg$avgfee) - log(dfg$val18)

dfg$ri <- factor(dfg$ri, levels = c(1,0))
dfg$state <- factor(dfg$state, levels = c(unique(dfg$state[dfg$state!="RI"]),"RI"))
ggplot(dfg, aes(x=t,y=y, group=state,  color=ri))+
  geom_line() +
  scale_color_manual(name=c(), values=c("black","gray70"), labels = c("RI","Others")) +
  geom_vline(xintercept = 18.5, linetype=3) +  
  theme(panel.background = element_rect(fill = 'gray96')) +
  scale_y_continuous(name="Log(Avg Interest Rate)", limits = c(-1,1)) +
  scale_x_continuous( name=c(), limits = c(0,60), breaks=c(1,13,25,37,49), labels=c("2009-01","2010-01",
                                                                                    "2011-01","2012-01","2013-01") ) +
  theme(legend.position = "none")
## end avg fee graph

## number of borrowers graph
adjust_period <- c( rep(18,7), 16, 17 )
varname_label <- read.csv("data/varname_label_for_graphs.csv", stringsAsFactors=FALSE)
for(i in c(1:9)){
  varname <- varname_label[i,"varname"]
  varlabel <- paste("Log(",varname_label[i,"label"],")", sep = "")
  cat(varlabel)
  dfg <- df
  #dfg <- subset(df, state=="RI" | state %in% find_parallel_trends(varname, 0.10) )
  dfg$y <- dfg[,varname]
  dfg <- subset(dfg, !is.na(y))
  
  dfg$ri <- factor(dfg$ri, levels = c(1,0))
  dfg$state <- factor(dfg$state, levels = c(unique(dfg$state[dfg$state!="RI"]),"RI"))
  
  fml <- paste("log(y) ~ log(nstores)*state + timedummy +", other_states_policies , sep = "")
  fml <- as.formula(fml)
  reg.tmp <- lm( fml , dfg)
  dfg$resid <- resid(reg.tmp)
  temp <- dfg[dfg$t== adjust_period[i] ,c("resid","state")]
  temp$val18 <- temp$resid
  temp$resid <- NULL
  dfg <- merge(dfg, temp, by="state")
  dfg$yy <- dfg$resid - dfg$val18
  
  gg <- ggplot(dfg, aes(x=t,y=yy, group=state,  color=ri))+
    geom_line() +
    scale_color_manual(name=c(), values=c("black","gray70"), labels = c("RI","Others")) +
    geom_vline(xintercept = 18.5, linetype=3) +
    theme(panel.background = element_rect(fill = 'gray96')) +
    scale_y_continuous(name=varlabel) +
    scale_x_continuous( name=c(), limits = c(0,60), breaks=c(1,13,25,37,49), labels=c("2009-01","2010-01",
                                                                                      "2011-01","2012-01","2013-01") ) +
    theme(legend.position = "none")
  
  img.filename <- paste("compare-cg1-",varname, ".eps", sep = "")
  
  ggsave(img.filename, plot = gg, device = "eps", path = "img/cg1",
         scale = 1, width = 4, height = 2, units = "in")
  
  print(gg)
  ## end number of borrowers graph
}
################################ CG1 ##################################



  


  