loanloss <- df %>% group_by(state) %>% summarize( avgdef = sum(avgdef0*nloans)/sum(nloans) )

wages <- read.csv("data/median-wage-2014.csv")
wages <- subset(wages, Occupation.Text == "Office and Administrative Support Occupations")
wages <- subset(wages, Job.Characteristic.Text == "Full-time")
wages <- subset(wages, Area.Level == "State area")
wages <- subset(wages, Work.Level.Text == "All levels")
states = read.csv("data/states.csv")
wages <- merge(wages[,c("Area.Text","Average.Hourly.Wage")], states, by.x = "Area.Text", by.y = "State")
wages$state <- wages$Abbreviation

rental <- read.csv("data/Apartment-List-Rent-Data.csv")
rental$rentvalue <- rental$Price_2014_01
rental <- rental[rental$Bedroom_Size=="2br",c("Location","rentvalue")]
rental <- merge(rental, states, by.x = "Location", by.y = "State")
rental$state <- rental$Abbreviation

costs <- merge(loanloss, wages, by = "state")
costs <- merge(costs, rental, by = "state")

ri_default <- costs$avgdef[costs$state=="RI"]
ri_wage <- costs$Average.Hourly.Wage[costs$state=="RI"]
ri_rental <- costs$rentvalue[costs$state=="RI"]
costs$index <- -( 0.21*(ri_default- costs$avgdef)/ri_default +
               0.40*(ri_wage - costs$Average.Hourly.Wage)/ri_wage +
                0.17*(ri_rental - costs$rentvalue) / ri_rental ) / (0.21+0.40+0.17)

#generate nice table output
costs_table <- costs[ costs$index<0.06 & ! costs$state %in% c("FL","OH"), c("Location","avgdef","Average.Hourly.Wage","rentvalue","index") ]
costs_table <- costs_table[order(costs_table$index),]  
costs_table$avgdef <- sprintf("%2.2f",costs_table$avgdef)
costs_table$index <- sprintf("%2.2f",costs_table$index)
rownames(costs_table) <- NULL

kable(costs_table, "latex", booktabs=T, 
      col.names = c("State","Default","Hourly Wage","Rent","Cost Index")) %>%
  row_spec(7, extra_latex_after = "\\rowcolor{gray!6}")

