install.packages("Synth")
library(Synth)

synthdata <- df_restrcited
synthdata$log_pop = log( synthdata$pop_interpolated )
synthdata$state_num <- as.numeric( as.factor(synthdata$state)  )
synthdata$pi_per_capita = exp(synthdata$log_pi_per_capita)

synthstates <- unique(synthdata$state_num)
state.ri <- synthdata$state_num[synthdata$state=="RI"][1]
state.control <- synthstates[synthstates!=state.treated]

synthdata2 <- synthdata

synth.results <- c()

for(i in 1:NROW(varname_label)){
  if(i==30){
    break
  }
  
  cat(varname_label[i,"varname"])
  synthdata <- synthdata2[!is.na(synthdata2[, varname_label[i,"varname"] ]),]
  synthdata$yy <- log(synthdata[, varname_label[i,"varname"] ])
  synthdata3 <- synthdata %>% group_by(state_num) %>% mutate(statemean=mean(ifelse(t<19,yy,NA),na.rm = T))
  synthdata$yy <- synthdata$yy - synthdata3$statemean
  
  synthdata$yy <- synthdata[, varname_label[i,"varname"] ]

gaps <- data.frame(state=c(), t=c(), g=c())
ri.synth <- c()

for(st in synthstates){
synthctl <- synthstates[synthstates!=st]
periods <- unique(synthdata$t)
pre_periods <- periods[periods<19]
dataprep.out <- dataprep(foo = synthdata,
                         predictors = c("pi_per_capita","unemp_rate","nstores","pop_interpolated"),
         predictors.op = "mean", special.predictors = NULL,
         dependent = "yy", unit.variable = "state_num",
         time.variable = "t", treatment.identifier = st,
         controls.identifier = synthctl, time.predictors.prior = pre_periods,
         time.optimize.ssr = pre_periods , time.plot = periods,
         unit.names.variable = "state")

synth.out <- synth(dataprep.out)
if( st == state.ri ){ 
  ri.synth <- synth.out$solution.w
}
gaps <- rbind(gaps, data.frame(state=st, t=periods, 
                               g = c(dataprep.out$Y1plot - (dataprep.out$Y0plot %*% synth.out$solution.w))))
}

gaps$gsq <- gaps$g ^ 2
msperatio <- gaps %>% group_by(state) %>% summarize( before = mean(ifelse(t<19,gsq,NA), na.rm = T), 
                                                       after = mean(ifelse(t>=19,gsq,NA), na.rm = T))
msperatio$msperatio <- msperatio$after / msperatio$before

rank <- NROW(msperatio[msperatio$msperatio>msperatio$msperatio[msperatio$state==state.ri],]) + 1
ri.synth <- c(ri.synth, rank)


dt <- subset(gaps, state==state.ri)
dt$after <- as.numeric(dt$t >= 19)
reg <- lm(g ~ after, dt)
cf <- coef(summary(reg))
ri.synth <- c(ri.synth, cf['after',1], cf['after',2])

synth.results <- cbind(synth.results,ri.synth)

gaps$state <- factor(gaps$state)
gg <- ggplot(data=gaps, aes(x=t, y=g, color=state, size=as.factor(state==state.ri))) +
  geom_line() +
  geom_vline( xintercept = 18.5)+
  scale_size_manual(values = c(0.5,1.5), labels=c("Others","RI") )+
  scale_x_continuous( name="Time (Months)", breaks=c(1,13,25,37,49), labels=c("2009-01","2010-01", 
                                                                              "2011-01","2012-01","2013-01") ) +
  scale_y_continuous(name="Gap between state and its synthetic control" ) +
  labs(color="", size="") +
  scale_color_discrete(guide = FALSE )

img.filename <- paste("cynth-graph-",varname, ".eps", sep = "")

#ggsave(img.filename, plot = gg, device = "eps", path = "img/cynth",
#scale = 1, width = 4, height = 2, units = "in")

}

sts <- unique(synthdata$state[synthdata$state!="RI"])
synth.results <- as.data.frame(t(synth.results))
colnames(synth.results) <- c(sts,"MSPR Rank","DiD b","DiD std")
rownames(synth.results) <- varname_label[,'label']

synth.results$tstat <- synth.results$`DiD b`/synth.results$`DiD std` 

for(i in 1:15){
  synth.results[i,'stars'] <- stars(synth.results[i,'tstat'],7)
}



### prepare synth results for table
synth.tbl <- synth.results

synth.tbl[,c(1:8)] <- lapply(synth.tbl[,c(1:8)], function(x){ sprintf("%3.1f",x*100) } )

synth.tbl[,10] <-  sprintf("%3.2f %s",synth.tbl$`DiD b`,strrep('*',synth.tbl$stars))

synth.tbl$stdstr <- sprintf("(%3.2f)",synth.tbl$`DiD std`)

synth.tbl <- cbind(varname_label[,'label'], synth.tbl)

synth.tbl <- synth.tbl[rep(1:nrow(synth.tbl),1,each=2),]

rownames(synth.tbl) <- NULL
synth.tbl[1:30 %% 2 == 0,'DiD b'] <- synth.tbl[1:30 %% 2 == 1,'stdstr']

synth.tbl <- synth.tbl[,c(1:9,11,10)]

synth.tbl <- synth.tbl %>% mutate_all(as.character)

for(i in seq(1,30,2)){
  for(j in c(2:9,11)){
    synth.tbl[i,j] <- sprintf("%s%s",synth.tbl[i,j], strrep("@",i))
    synth.tbl[i+1,j] <- sprintf("%s%s",synth.tbl[i+1,j], strrep("@",i))
  }
}


kk <- kable(synth.tbl, "latex", booktabs=T, 
      col.names = c("",sts,"DiD Estimate","RI Rank")) %>%
  kable_styling(latex_options = c("scale_down")) %>%
  add_header_above( c(" " = 1, "RI Synthetic Control Weights (%)" = 8, " " = 2)) %>%
  collapse_rows(columns = c(1:9,11), latex_hline = "major", valign = "middle") %>%
  footnote(general = "The weights represent the weight given to each state to construct a synthetic control for Rhode Island. 
The DiD estimate is the result of a difference in difference regression between Rhode Island and its synthetic control.
* p < 0.10, ** p < 0.05, *** p < 0.01
RI Rank shows the rank (in descending order) of Rhode Island's MSRE Ratio among those of the placebo treatments.          
           "
           ,threeparttable = T
  )


gsub("@",'',kk)













